@@ -39,6 +39,7 @@ def _datasets_deprecation_warning():
         "removed in Verde v2.0.0. The tutorials/examples will transition "
         "to using Ensaio (https://www.fatiando.org/ensaio/) instead.",
         DeprecationWarning,
+        stacklevel=2,
     )
 
 
@@ -46,6 +47,13 @@ def locate():
     r"""
     The absolute path to the sample data storage location on disk.
 
+    .. warning::
+
+        All sample datasets in Verde are deprecated and will be
+        **removed in Verde v2.0.0**.
+        The tutorials/examples will transition to using
+        `Ensaio <https://www.fatiando.org/ensaio/>`__ instead.
+
     This is where the data are saved on your computer. The location is
     dependent on the operating system. The folder locations are defined by the
     ``appdirs``  package (see the `appdirs documentation
@@ -151,7 +159,8 @@ def setup_baja_bathymetry_map(
     if kwargs:
         warnings.warn(
             "All kwargs are being ignored. They are accepted to "
-            + "guarantee backward compatibility."
+            + "guarantee backward compatibility.",
+            stacklevel=2,
         )
     _setup_map(
         ax,
@@ -210,6 +219,7 @@ def fetch_rio_magnetic():
         "The Rio magnetic anomaly dataset is deprecated and will be removed "
         "in Verde v2.0.0. Use a different dataset instead.",
         FutureWarning,
+        stacklevel=2,
     )
     data_file = REGISTRY.fetch("rio-magnetic.csv.xz")
     data = pd.read_csv(data_file, compression="xz")
@@ -243,6 +253,7 @@ def setup_rio_magnetic_map(ax, region=(-42.6, -42, -22.5, -22)):
         "The Rio magnetic anomaly dataset is deprecated and will be removed "
         "in Verde v2.0.0. Use a different dataset instead.",
         FutureWarning,
+        stacklevel=2,
     )
     _setup_map(
         ax,
@@ -330,7 +341,8 @@ def setup_california_gps_map(
     if kwargs:
         warnings.warn(
             "All kwargs are being ignored. They are accepted to "
-            + "guarantee backward compatibility."
+            + "guarantee backward compatibility.",
+            stacklevel=2,
         )
     _setup_map(
         ax,
@@ -409,7 +421,8 @@ def setup_texas_wind_map(ax, region=(-107, -93, 25.5, 37), coastlines=True, **kw
     if kwargs:
         warnings.warn(
             "All kwargs are being ignored. They are accepted to "
-            + "guarantee backward compatibility."
+            + "guarantee backward compatibility.",
+            stacklevel=2,
         )
     _setup_map(
         ax,
