@@ -60,11 +60,13 @@ class SplineCV(BaseGridder):
 
     Parameters
     ----------
-    mindists : iterable or 1d array
+    mindists : iterable or 1d array or None
+        **DEPRECATED:** This argument is no longer needed and will be removed
+        in Verde 2.0.0. This fudge factor is no longer required since a new
+        formulation eliminates the singularity at zero distance. Use the
+        default value of ``mindists=None`` to get the future behaviour.
         List (or other iterable) of *mindist* parameter values to try. Can be
         considered a minimum distance between the point forces and data points.
-        Needed because the Green's functions are singular when forces and data
-        points coincide. Acts as a fudge factor.
     dampings : iterable or 1d array
         List (or other iterable) of *damping* parameter values to try. Is the
         positive damping regularization parameter. Controls how much smoothness
@@ -74,11 +76,12 @@ class SplineCV(BaseGridder):
         (default), then will be set to the data coordinates the first time
         :meth:`~verde.SplineCV.fit` is called.
     engine : str
-        Computation engine for the Jacobian matrix and prediction. Can be
-        ``'auto'``, ``'numba'``, or ``'numpy'``. If ``'auto'``, will use numba
-        if it is installed or numpy otherwise. The numba version is
-        multi-threaded and usually faster, which makes fitting and predicting
-        faster.
+        **DEPRECATED:** This option is deprecated and will be removed in Verde
+        v2.0.0. The numba engine will be the only option. Computation engine
+        for the Jacobian matrix and prediction. Can be ``'auto'``, ``'numba'``,
+        or ``'numpy'``. If ``'auto'``, will use numba if it is installed or
+        numpy otherwise. The numba version is multi-threaded and usually
+        faster, which makes fitting and predicting faster.
     cv : None or cross-validation generator
         Any scikit-learn cross-validation generator. If not given, will use the
         default set by :func:`verde.cross_val_score`.
@@ -91,6 +94,11 @@ class SplineCV(BaseGridder):
         If True, will use :func:`dask.delayed` to dispatch computations and
         allow mod:`dask` to execute the grid search in parallel (see note
         above).
+    scoring : None, str, or callable
+        The scoring function (or name of a function) used for cross-validation.
+        Must be known to scikit-learn. See the description of *scoring* in
+        :func:`sklearn.model_selection.cross_val_score` for details. If None,
+        will fall back to the :meth:`verde.Spline.score` method.
 
     Attributes
     ----------
@@ -126,28 +134,50 @@ class SplineCV(BaseGridder):
 
     def __init__(
         self,
-        mindists=(1e3, 10e3, 100e3),
+        mindists=None,
         dampings=(1e-10, 1e-5, 1e-1),
         force_coords=None,
         engine="auto",
         cv=None,
         client=None,
         delayed=False,
+        scoring=None,
     ):
         super().__init__()
         self.dampings = dampings
-        self.mindists = mindists
+        if mindists is None:
+            self.mindists = [0]
+        else:
+            self.mindists = mindists
+            warnings.warn(
+                "The mindists parameter of verde.SplineCV is no longer "
+                "required and will be removed in Verde 2.0.0. Use the default "
+                "value to obtain the future behavior.",
+                FutureWarning,
+                stacklevel=2,
+            )
         self.force_coords = force_coords
         self.engine = engine
         self.cv = cv
         self.client = client
         self.delayed = delayed
+        self.scoring = scoring
+        if engine != "auto":
+            warnings.warn(
+                "The 'engine' parameter of 'verde.SplineCV' is "
+                "deprecated and will be removed in Verde 2.0.0. "
+                "The faster and memory efficient numba engine will be "
+                "the only option.",
+                FutureWarning,
+                stacklevel=2,
+            )
         if client is not None:
             warnings.warn(
                 "The 'client' parameter of 'verde.SplineCV' is "
                 "deprecated and will be removed in Verde 2.0.0. "
                 "Use the 'delayed' parameter instead.",
                 FutureWarning,
+                stacklevel=2,
             )
 
     def fit(self, coordinates, data, weights=None):
@@ -220,6 +250,7 @@ class SplineCV(BaseGridder):
                     weights=weights,
                     cv=self.cv,
                     delayed=self.delayed,
+                    scoring=self.scoring,
                 )
                 scores.append(dispatch(np.mean, delayed=self.delayed)(score))
         best = dispatch(np.argmax, delayed=self.delayed)(scores)
@@ -325,10 +356,12 @@ class Spline(BaseGridder):
 
     Parameters
     ----------
-    mindist : float
-        A minimum distance between the point forces and data points. Needed
-        because the Green's functions are singular when forces and data points
-        coincide. Acts as a fudge factor.
+    mindist : float or None
+        **DEPRECATED:** This argument is no longer needed and will be removed
+        in Verde 2.0.0. This fudge factor is no longer required since a new
+        formulation eliminates the singularity at zero distance. Use the
+        default value of ``mindist=None`` to get the future behaviour. A
+        minimum distance between the point forces and data points.
     damping : None or float
         The positive damping regularization parameter. Controls how much
         smoothness is imposed on the estimated forces. If None, no
@@ -338,11 +371,12 @@ class Spline(BaseGridder):
         (default), then will be set to the data coordinates used to fit the
         spline.
     engine : str
-        Computation engine for the Jacobian matrix and prediction. Can be
-        ``'auto'``, ``'numba'``, or ``'numpy'``. If ``'auto'``, will use numba
-        if it is installed or numpy otherwise. The numba version is
-        multi-threaded and usually faster, which makes fitting and predicting
-        faster.
+        **DEPRECATED:** This option is deprecated and will be removed in Verde
+        v2.0.0. The numba engine will be the only option. Computation engine
+        for the Jacobian matrix and prediction. Can be ``'auto'``, ``'numba'``,
+        or ``'numpy'``. If ``'auto'``, will use numba if it is installed or
+        numpy otherwise. The numba version is multi-threaded and usually
+        faster, which makes fitting and predicting faster.
 
     Attributes
     ----------
@@ -363,12 +397,31 @@ class Spline(BaseGridder):
 
     """
 
-    def __init__(self, mindist=1e-5, damping=None, force_coords=None, engine="auto"):
+    def __init__(self, mindist=None, damping=None, force_coords=None, engine="auto"):
         super().__init__()
-        self.mindist = mindist
         self.damping = damping
         self.force_coords = force_coords
         self.engine = engine
+        if engine != "auto":
+            warnings.warn(
+                "The 'engine' parameter of 'verde.Spline' is "
+                "deprecated and will be removed in Verde 2.0.0. "
+                "The faster and memory efficient numba engine will be "
+                "the only option.",
+                FutureWarning,
+                stacklevel=2,
+            )
+        if mindist is None:
+            self.mindist = 0
+        else:
+            self.mindist = mindist
+            warnings.warn(
+                "The mindist parameter of verde.Spline is no longer required "
+                "and will be removed in Verde 2.0.0. Use the default value "
+                "to obtain the future behavior.",
+                FutureWarning,
+                stacklevel=2,
+            )
 
     def fit(self, coordinates, data, weights=None):
         """
@@ -503,24 +556,60 @@ def warn_weighted_exact_solution(spline, weights):
     if weights is not None and spline.damping is None:
         warnings.warn(
             "Weights might have no effect if no regularization is used. "
-            "Use damping or specify force positions that are different from the data."
+            "Use damping or specify force positions that are different from the data.",
+            stacklevel=2,
         )
 
 
-def greens_func(east, north, mindist):
+def greens_func_numpy(east, north, mindist):
     "Calculate the Green's function for the Bi-Harmonic Spline"
     distance = np.sqrt(east**2 + north**2)
-    # The mindist factor helps avoid singular matrices when the force and
-    # computation point are too close
+    # The mindist factor was used to avoid NaNs when the distance approaches
+    # zero and the log tents to -infinity. This is no longer needed with
+    # current implementation below. Keep it for compatibility only but remove
+    # in Verde 2.0.0.
     distance += mindist
-    return (distance**2) * (np.log(distance) - 1)
+    # Calculate this way instead of x²(log(x) - 1) to avoid calculating log of
+    # 0. The limit for this as x->0 is 0 anyway. This is good for small values
+    # of distance but for larger distances it fails because of an overflow in
+    # the power operator. Saw this on Wikipedia but there was no citation in
+    # December 2022: https://en.wikipedia.org/wiki/Radial_basis_function
+    result = np.empty_like(distance)
+    small = distance < 1
+    big = ~small
+    result[small] = distance[small] * (
+        np.log(distance[small] ** distance[small]) - distance[small]
+    )
+    result[big] = distance[big] ** 2 * (np.log(distance[big]) - 1)
+    return result
+
+
+@jit(nopython=True)
+def greens_func_jit(east, north, mindist):
+    "Calculate the Green's function for the Bi-Harmonic Spline"
+    distance = np.sqrt(east**2 + north**2)
+    # The mindist factor was used to avoid NaNs when the distance approaches
+    # zero and the log tents to -infinity. This is no longer needed with
+    # current implementation below. Keep it for compatibility only but remove
+    # in Verde 2.0.0.
+    distance += mindist
+    # Calculate this way instead of x²(log(x) - 1) to avoid calculating log of
+    # 0. The limit for this as x->0 is 0 anyway. This is good for small values
+    # of distance but for larger distances it fails because of an overflow in
+    # the power operator. Saw this on Wikipedia but there was no citation in
+    # December 2022: https://en.wikipedia.org/wiki/Radial_basis_function
+    if distance < 1:
+        result = distance * (np.log(distance**distance) - distance)
+    else:
+        result = distance**2 * (np.log(distance) - 1)
+    return result
 
 
 def predict_numpy(east, north, force_east, force_north, mindist, forces, result):
     "Calculate the predicted data using numpy."
     result[:] = 0
     for j in range(forces.size):
-        green = greens_func(east - force_east[j], north - force_north[j], mindist)
+        green = greens_func_numpy(east - force_east[j], north - force_north[j], mindist)
         result += green * forces[j]
     return result
 
@@ -529,7 +618,7 @@ def jacobian_numpy(east, north, force_east, force_north, mindist, jac):
     "Calculate the Jacobian using numpy broadcasting."
     # Reshaping the data to a column vector will automatically build a distance
     # matrix between each data point and force.
-    jac[:] = greens_func(
+    jac[:] = greens_func_numpy(
         east.reshape((east.size, 1)) - force_east,
         north.reshape((north.size, 1)) - force_north,
         mindist,
@@ -537,29 +626,25 @@ def jacobian_numpy(east, north, force_east, force_north, mindist, jac):
     return jac
 
 
-@jit(nopython=True, fastmath=True, parallel=True)
+@jit(nopython=True, parallel=True)
 def predict_numba(east, north, force_east, force_north, mindist, forces, result):
     "Calculate the predicted data using numba to speed things up."
     for i in numba.prange(east.size):
         result[i] = 0
         for j in range(forces.size):
-            green = GREENS_FUNC_JIT(
+            green = greens_func_jit(
                 east[i] - force_east[j], north[i] - force_north[j], mindist
             )
             result[i] += green * forces[j]
     return result
 
 
-@jit(nopython=True, fastmath=True, parallel=True)
+@jit(nopython=True, parallel=True)
 def jacobian_numba(east, north, force_east, force_north, mindist, jac):
     "Calculate the Jacobian matrix using numba to speed things up."
     for i in numba.prange(east.size):
         for j in range(force_east.size):
-            jac[i, j] = GREENS_FUNC_JIT(
+            jac[i, j] = greens_func_jit(
                 east[i] - force_east[j], north[i] - force_north[j], mindist
             )
     return jac
-
-
-# Jit compile the Green's functions for use in the numba functions
-GREENS_FUNC_JIT = jit(nopython=True, fastmath=True)(greens_func)
