@@ -7,8 +7,6 @@
 """
 Test the base classes and their utility functions.
 """
-import warnings
-
 import numpy as np
 import numpy.testing as npt
 import pytest
@@ -150,7 +148,8 @@ def test_basegridder():
     # Grid on profile
     prof = grd.profile((0, -10), (10, -10), 30)
     # Grid on scatter
-    scat = grd.scatter(region=region, size=1000, random_state=0)
+    with pytest.warns(FutureWarning):
+        scat = grd.scatter(region=region, size=1000, random_state=0)
 
     for grid in grids:
         npt.assert_allclose(grid.scalars.values, data_true)
@@ -388,15 +387,6 @@ def test_basegridder_grid_invalid_arguments():
     # Check error is raised if both coordinates and region are passed
     with pytest.raises(ValueError):
         grd.grid(coordinates=grid_coords, region=region)
-    # Check if FutureWarning is raised after passing region, spacing or shape
-    with warnings.catch_warnings(record=True) as warns:
-        grd.grid(region=region, shape=(4, 4))
-        assert len(warns) == 1
-        assert issubclass(warns[0].category, FutureWarning)
-    with warnings.catch_warnings(record=True) as warns:
-        grd.grid(region=region, spacing=1)
-        assert len(warns) == 1
-        assert issubclass(warns[0].category, FutureWarning)
 
 
 def test_check_fit_input():
